package com.srs.routine.mapper;

import java.util.List;

import com.srs.routine.domain.RtFuSolt;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.routine.domain.vo.RtfuRuleVo;

/**
 * 功能房开放时间段Mapper接口
 *
 * @author srs
 * @date 2024-07-19
 */
public interface RtFuSoltMapper extends BaseMapper<RtFuSolt> {
    /**
     * 查询功能房开放时间段
     *
     * @param id 功能房开放时间段主键
     * @return 功能房开放时间段
     */
    public RtFuSolt selectRtFuSoltById(Long id);

    /**
     * 查询功能房开放时间段列表
     *
     * @param rtFuSolt 功能房开放时间段
     * @return 功能房开放时间段集合
     */
    List<RtFuSolt> selectRtFuSoltList(RtFuSolt rtFuSolt);

    List<RtfuRuleVo> selectRtFuSoltLists(RtFuSolt rtFuSolt);

    RtFuSolt selectRtFSoles(RtFuSolt rtFuSolt);


    List<RtfuRuleVo> selectRtFuSoltRule(RtfuRuleVo rtfuRuleVo);
    /**
     * 新增功能房开放时间段
     *
     * @param rtFuSolt 功能房开放时间段
     * @return 结果
     */
    int insertRtFuSolt(RtFuSolt rtFuSolt);

    /**
     * 修改功能房开放时间段
     *
     * @param rtFuSolt 功能房开放时间段
     * @return 结果
     */
    int updateRtFuSolt(RtFuSolt rtFuSolt);

    /**
     * 删除功能房开放时间段
     *
     * @param id 功能房开放时间段主键
     * @return 结果
     */
    int deleteRtFuSoltById(Long id);

    /**
     * 批量删除功能房开放时间段
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteRtFuSoltByIds(Long[] ids);
}
